@@ -204,7 +204,7 @@ fn test_load_file_error_contains_filename() {
         assert_eq!(
             err.to_string(),
             format!(
-                "did not expect to find the token ';' at line 1, column 1 in file {}",
+                "did not expect to find the token ';' at line 1, column 1 of file {}:\n\t001: ;\n\t     ^\n",
                 tempfile.path().to_string_lossy().into_owned()
             )
         );
@@ -245,15 +245,12 @@ fn test_already_loaded_file_error() -> oso::Result<()> {
     let err = oso.oso.load_files(vec![&path, &path]).unwrap_err();
 
     assert!(
-        matches!(&err,
-        OsoError::Polar(polar_error::PolarError {
-            kind:
-                polar_error::ErrorKind::Runtime(polar_error::RuntimeError::FileLoading { .. }),
+        matches!(&err, OsoError::Polar(polar_error::PolarError {
+            kind: polar_error::ErrorKind::Validation(polar_error::ValidationError::FileLoading { .. }),
             ..
-        })
-    if err.to_string() == format!("Problem loading file: File {} has already been loaded.", path.to_string_lossy())),
-        "Error was {:?}",
-        &err
+        }) if err.to_string().starts_with(&format!("Problem loading file: File {} has already been loaded.", path.to_string_lossy()))),
+        "Error was {}",
+        err
     );
 
     Ok(())
